@@ -28,7 +28,7 @@ use Try::Tiny;
 
 use Moo 2.000000;
 
-our $VERSION = '0.56';
+our $VERSION = '0.57';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -128,7 +128,7 @@ has 'refresh_cache' => (
 
 has 'root_dir' => (
     is       => 'ro',
-    isa      => t('RealDir')->_subify,
+    isa      => t('RealDir'),
     coerce   => t('RealDir')->coercion_sub,
     required => 1
 );
@@ -795,7 +795,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.56
+version 0.57
 
 =head1 SYNOPSIS
 
